@@ -32,7 +32,7 @@
 #define SND_SEQ_IBUF_SIZE	500		/* in event_size aligned */
 #define DEFAULT_TMPBUF_SIZE	20
 
-typedef struct sndrv_seq_queue_client snd_seq_queue_client_t;
+typedef struct snd_seq_queue_client snd_seq_queue_client_t;
 
 
 typedef struct {
@@ -77,7 +77,7 @@ struct _snd_seq {
 	int mode;
 	int poll_fd;
 	void *dl_handle;
-	snd_seq_ops_t *ops;
+	const snd_seq_ops_t *ops;
 	void *private_data;
 	int client;		/* client number */
 	/* buffers */
